@@ -55,9 +55,9 @@ public:
     Q_INVOKABLE void uninstall(const QString &plugin);
 
 public Q_SLOTS:
-    void load();
-    void save();
-    void defaults();
+    void load() Q_DECL_OVERRIDE;
+    void save() Q_DECL_OVERRIDE;
+    void defaults() Q_DECL_OVERRIDE;
 
 Q_SIGNALS:
     void selectedPluginChanged();
